==> vue-testing-library-0.1.12.tgz: package/npm/__tests__/vuex.js <==
import VuexTest from './components/VuexTest';
import { render, Simulate } from '../';
import Vuex from 'vuex';

var store = {
  state: {
    count: 0
  },
  actions: {
    increment: function increment(_ref) {
      var commit = _ref.commit,
          state = _ref.state;
      return commit('SET_COUNT', state.count + 1);
    },
    decrement: function decrement(_ref2) {
      var commit = _ref2.commit,
          state = _ref2.state;
      return commit('SET_COUNT', state.count - 1);
    }
  },
  mutations: {
    SET_COUNT: function SET_COUNT(state, count) {
      return state.count = count;
    }
  }
};

test('can render with vuex with defaults', function () {
  var _render = render(VuexTest, { store: store }),
      getByTestId = _render.getByTestId,
      getByText = _render.getByText;

  Simulate.click(getByText('+'));
  expect(getByTestId('count-value').textContent).toBe('1');
});

test('can render with vuex with custom initial state', function () {
  store.state.count = 3;

  var _render2 = render(VuexTest, { store: store }),
      getByTestId = _render2.getByTestId,
      getByText = _render2.getByText;

  Simulate.click(getByText('-'));
  expect(getByTestId('count-value').textContent).toBe('2');
});

test('can render with vuex with custom store', function () {
  // this is a silly store that can never be changed
  var store = { state: { count: 1000 } };

  var _render3 = render(VuexTest, { store: store }),
      getByTestId = _render3.getByTestId,
      getByText = _render3.getByText;

  Simulate.click(getByText('+'));
  expect(getByTestId('count-value').textContent).toBe('1000');
  Simulate.click(getByText('-'));
  expect(getByTestId('count-value').textContent).toBe('1000');
});

==> vue-testing-library-0.2.1.tgz: package/npm/__tests__/vuex.js <==
'use strict';

var _VuexTest = require('./components/VuexTest');

var _VuexTest2 = _interopRequireDefault(_VuexTest);

var _ = require('../');

var _vuex = require('vuex');

var _vuex2 = _interopRequireDefault(_vuex);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var store = {
  state: {
    count: 0
  },
  actions: {
    increment: function increment(_ref) {
      var commit = _ref.commit,
          state = _ref.state;
      return commit('SET_COUNT', state.count + 1);
    },
    decrement: function decrement(_ref2) {
      var commit = _ref2.commit,
          state = _ref2.state;
      return commit('SET_COUNT', state.count - 1);
    }
  },
  mutations: {
    SET_COUNT: function SET_COUNT(state, count) {
      return state.count = count;
    }
  }
};

test('can render with vuex with defaults', function () {
  var _render = (0, _.render)(_VuexTest2.default, { store: store }),
      getByTestId = _render.getByTestId,
      getByText = _render.getByText;

  _.Simulate.click(getByText('+'));
  expect(getByTestId('count-value').textContent).toBe('1');
});

test('can render with vuex with custom initial state', function () {
  store.state.count = 3;

  var _render2 = (0, _.render)(_VuexTest2.default, { store: store }),
      getByTestId = _render2.getByTestId,
      getByText = _render2.getByText;

  _.Simulate.click(getByText('-'));
  expect(getByTestId('count-value').textContent).toBe('2');
});

test('can render with vuex with custom store', function () {
  // this is a silly store that can never be changed
  var store = { state: { count: 1000 } };

  var _render3 = (0, _.render)(_VuexTest2.default, { store: store }),
      getByTestId = _render3.getByTestId,
      getByText = _render3.getByText;

  _.Simulate.click(getByText('+'));
  expect(getByTestId('count-value').textContent).toBe('1000');
  _.Simulate.click(getByText('-'));
  expect(getByTestId('count-value').textContent).toBe('1000');
});
